Pro spawn_astrometrynet_api, command_in, _REF_EXTRA=extra, TIMER=timer, INTERVAL=interval, MSG=msg, STATUS=status, TXTHEADER=txtheader
  ;Thanks to EXELISVIS technical support engineers Jim Uba and Fernando Santoro for help in building this routine.
  ;Adapted from spawn_timer.pro by Jonathan Gagne, April 25, 2014. 
  ;MODIFIED, Jonathan Gagne, April 25, 2014 : Removed the "wait, 5" after launching process, and instead asks that the code's been running for at least 250s before declaring the child process didn't launch properly
  ;MODIFIED, Jonathan Gagne, April 30, 2014 : Changed structure of spawn for a more efficient catch of the Python child process PID

  forward_function readcol, trim, round

  command = command_in
  if ~keyword_set(msg) then msg = ''

  tmpfile = 'tmp_output_api_'+strjoin(strjoin(strsplit(systime( /utc ),' :',/ext),'-'))+'.txt'
  if file_test(tmpfile) then file_delete, tmpfile, /quiet

  if !version.os ne 'linux' and !version.os ne 'darwin' then $
    message, 'This routine is meant to run on UNIX or DARWIN (MAC OS X) machines only !'
  
  SPAWN, command+' > '+tmpfile+' & > /dev/null ; echo $!', pid, err, _EXTRA=extra
  if strtrim(err,2L) ne '' then message, ' SPAWN encountered an error : '+err
  
  if keyword_set(timer) then $
    maxpolls = timer else $
    maxpolls = -100
  if keyword_set(interval) then $
    pollinterval = interval else $
    pollinterval = 1  ; seconds
  npolls = 0
  nlines = 0L
  status = 0L
  
  WHILE 1 DO BEGIN
    
    if file_test(tmpfile) then begin
      readcol,tmpfile,lines,format='A',delimiter='ç',/silent
      if n_elements(lines) gt nlines then begin
        if keyword_set(timer) then print, msg+' Child Process used up '+trim(float(round(float(npolls)/float(maxpolls)*100.*1d3))/1d3)+' % of allowed time ('+trim(float(round(float(npolls)*float(pollinterval)/60.*10.))/10.)+'/'+trim(float(round(float(maxpolls)*float(pollinterval)/60.*10.))/10.)+' minutes)...'
        if keyword_set(txtheader) then print, txtheader
        print, transpose(lines[nlines:*])
        if max(strpos(lines,'Got status: failure')) ne -1L then $
          status = -1
        if max(strpos(lines,'Wrote to ')) ne -1L then $
          status = -2
        if status ne 0 then BREAK
        if keyword_set(txtheader) then print, txtheader
      endif
      if status ne 0 then BREAK
      nlines = n_elements(lines)
    endif

    ; If the number of poll iterations exceeds limit then break out of loop
    ; and set status to -1
    if keyword_set(timer) and npolls GE maxpolls THEN BEGIN
      status = -1
      BREAK
    ENDIF
    
    ; Get the PIDs of the processes owned by the current user
    if !version.os eq 'linux' then SPAWN, 'ps -a -o pid --no-heading', out
    if !version.os eq 'darwin' then SPAWN, 'ps -a -p '+pid, out

    ; Check for presence of PID in returned PID listing "out"
    pid_exists = max(strpos(out,'python') ne -1L)
    
    IF pid_exists Gt 0 THEN $
      WAIT, pollinterval  $  ; PID is still present PID list so wait before polling again
    ELSE BEGIN  ; Otherwise, PID no longer present so stop polling
      ;Wait at least 20s before declaring that the child process didn't launch properly
      if npolls ge (250./pollinterval) then begin
        status = 0
        BREAK
      endif
    ENDELSE

    npolls++

  ENDWHILE

  IF status eq -1 THEN BEGIN
    if !version.os eq 'linux' then SPAWN, 'kill -TERM -'+pid
    if !version.os eq 'darwin' then SPAWN, 'kill -9 '+pid
  ENDIF
  
  msg2 = status EQ -2 ? $
    '> Spawn process *not killed* by IDL' : $
    '> Spawn process *killed* by IDL'
  
  PRINT, msg2

  if file_test(tmpfile) then file_delete, tmpfile, /quiet

end